.. _using_mdt:

#########
Using MDT
#########
The primary usage of MDT is model fitting, otherwise known as :ref:`Maximum Likelihood Estimation <model_fitting>`.
This is the feature most users will be interested in.

Some users may additionally be interested in model sampling using Markov Chain Monte Carlo sampling, in :ref:`MCMC sampling <model_sampling>`.

For adding your own models, or adapting existing models, MDT has a flexible component based plug-in system.
This system, described in :ref:`adding components <components>` allows you to extend MDT simply by placing python script files in your home directory.

MDT also offers a :ref:`Maps visualizer <mdt_maps_visualizer>` to quickly visualize your MDT results.
This visualizer is highly customizable and can provide paper ready figures.

Additional technicalities can be found in :ref:`design concepts <design_concepts>` and :ref:`Advanced configuration <configuration>`.
